#####################################################################
##  rpud : An R packge for GPU computing
##  Copyright (C) 2010-2016 Chi Yau
##

library(e1071)
library(SparseM)

filepath <- system.file("runit/data/rpusvm/heart_scale", package = "rpud")
hs <- read.svm.data(filepath, fac=TRUE)

x <- hs$x
y <- hs$y
y1 <- as.numeric(y)

scale <- FALSE
kernel <- "sigmoid"

gamma <- 0.25
coef0 <- 0.16

test.svm.sparse.kernel.sigmoid.s0 <- function() {
	
	type <- "C-classification"
	model.libsvm <- e1071::svm(x, y, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale)
	pred.libsvm <- fitted(model.libsvm)
	
	model.rpusvm <- rpusvm(x, y, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale) 
	pred.rpusvm <- fitted(model.rpusvm)
	
	error.libsvm <- sum(pred.libsvm != y)
	error.rpusvm <- sum(pred.rpusvm != y)
	checkEqualsNumeric(error.libsvm, error.rpusvm, tolerance=1)
}

test.svm.sparse.kernel.sigmoid.s1 <- function() {
	
	type <- "nu-classification"
	
	model.libsvm <- e1071::svm(x, y, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale)
	pred.libsvm <- fitted(model.libsvm)
	
	model.rpusvm <- rpusvm(x, y, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale) 
	pred.rpusvm <- fitted(model.rpusvm)
	
	error.libsvm <- sum(pred.libsvm != y)
	error.rpusvm <- sum(pred.rpusvm != y)
	checkEquals(error.libsvm, error.rpusvm)
}

test.svm.sparse.kernel.sigmoid.s2 <- function() {
	
	type <- "one-classification"
	
	model.libsvm <- e1071::svm(x, y, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale)
	pred.libsvm <- fitted(model.libsvm)
	
	model.rpusvm <- rpusvm(x, y, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale) 
	pred.rpusvm <- fitted(model.rpusvm)
	
	error.libsvm <- sum(pred.libsvm != y)
	error.rpusvm <- sum(pred.rpusvm != y)
	checkEquals(error.libsvm, error.rpusvm)
}

test.svm.sparse.kernel.sigmoid.s3 <- function() {
	
	type <- "eps-regression"
	
	model.libsvm <- e1071::svm(x, y1, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale)
	pred.libsvm <- fitted(model.libsvm)
	
	model.rpusvm <- rpusvm(x, y1, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale) 
	pred.rpusvm <- fitted(model.rpusvm)
	
#	checkEqualsNumeric(pred.libsvm, pred.rpusvm, tolerance=1.e-03)
	checkEqualsNumeric(pred.libsvm, pred.rpusvm, tolerance=2)
}

test.svm.sparse.kernel.sigmoid.s4 <- function() {
	
	type <- "nu-regression"
	
	model.libsvm <- e1071::svm(x, y1, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale)
	pred.libsvm <- fitted(model.libsvm)
	
	model.rpusvm <- rpusvm(x, y1, type=type, kernel=kernel, gamma=gamma, coef0=coef0, scale=scale) 
	pred.rpusvm <- fitted(model.rpusvm)
	
#	checkEqualsNumeric(pred.libsvm, pred.rpusvm, tolerance=1.e-03)
	checkEqualsNumeric(pred.libsvm, pred.rpusvm, tolerance=0.5)
}

.tearDown <- function() {
    flush.console()
}

